"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTAsymmetricVerifierProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const fs = tslib_1.__importStar(require("fs/promises"));
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const keys_1 = require("../keys");
let JWTAsymmetricVerifierProvider = class JWTAsymmetricVerifierProvider {
    constructor(authConfig) {
        this.authConfig = authConfig;
    }
    value() {
        return async (code, options) => {
            var _a, _b;
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            let publicKey; //NOSONAR
            let payload;
            if ((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useSymmetricEncryption) {
                payload = jwt.verify(code, process.env.JWT_SECRET, {
                    ...options,
                    issuer: process.env.JWT_ISSUER,
                    algorithms: ['HS256'],
                });
            }
            else {
                publicKey = (await fs.readFile((_b = process.env.JWT_PUBLIC_KEY) !== null && _b !== void 0 ? _b : ''));
                payload = jwt.verify(code, publicKey, {
                    ...options,
                    issuer: process.env.JWT_ISSUER,
                    algorithms: ['RS256'],
                });
            }
            return payload;
        };
    }
};
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider;
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [Object])
], JWTAsymmetricVerifierProvider);
//# sourceMappingURL=jwt-verify.provider.js.map