import { Getter } from '@loopback/core';
import { BelongsToAccessor, DataObject, Entity, HasManyRepositoryFactory, HasOneRepositoryFactory } from '@loopback/repository';
import { Options } from '@loopback/repository/src/common-types';
import { SequelizeDataSource } from '@loopback/sequelize';
import { ILogger } from '@sourceloop/core';
import { SequelizeSoftCrudRepository } from 'loopback4-soft-delete/sequelize';
import { Tenant, User, UserCredentials, UserRelations, UserTenant } from '../../models';
import { PasswordDecryptionFn } from '../../providers';
import { OtpRepository } from '../otp.repository';
import { TenantRepository } from './tenant.repository';
import { UserCredentialsRepository } from './user-credentials.repository';
import { UserTenantRepository } from './user-tenant.repository';
export declare class UserRepository extends SequelizeSoftCrudRepository<User, typeof User.prototype.id, UserRelations> {
    getOtpRepository: Getter<OtpRepository>;
    protected tenantRepositoryGetter: Getter<TenantRepository>;
    protected userTenantRepositoryGetter: Getter<UserTenantRepository>;
    private readonly logger;
    private readonly passwordDecryptionFn;
    private readonly user;
    readonly credentials: HasOneRepositoryFactory<UserCredentials, typeof User.prototype.id>;
    readonly tenant: BelongsToAccessor<Tenant, typeof User.prototype.id>;
    readonly userTenants: HasManyRepositoryFactory<UserTenant, typeof User.prototype.id>;
    constructor(dataSource: SequelizeDataSource, getUserCredsRepository: Getter<UserCredentialsRepository>, getOtpRepository: Getter<OtpRepository>, tenantRepositoryGetter: Getter<TenantRepository>, userTenantRepositoryGetter: Getter<UserTenantRepository>, logger: ILogger, passwordDecryptionFn: PasswordDecryptionFn, user: typeof Entity & {
        prototype: User;
    });
    create(entity: DataObject<User>, options?: Options): Promise<User>;
    createWithoutPassword(entity: DataObject<User>, options?: Options): Promise<User>;
    verifyPassword(username: string, password: string): Promise<User>;
    decryptPassword(password: string): Promise<string>;
    updatePassword(username: string, password: string, newPassword: string): Promise<User>;
    changePassword(username: string, newPassword: string, oldPassword?: string): Promise<User>;
    updateLastLogin(userId: string): Promise<void>;
    firstTimeUser(userId: string): Promise<boolean>;
}
