"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoginActivityHelperService = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const repositories_1 = require("../repositories");
let LoginActivityHelperService = class LoginActivityHelperService {
    constructor(getCurrentUser, tenantGuardService, loginActivityRepository) {
        this.getCurrentUser = getCurrentUser;
        this.tenantGuardService = tenantGuardService;
        this.loginActivityRepository = loginActivityRepository;
    }
    async find(filter, options) {
        const updatedFilter = filter !== null && filter !== void 0 ? filter : new repository_1.FilterBuilder().build();
        const user = await this.getCurrentUser();
        if (user.tenantId) {
            updatedFilter.where = this.tenantGuardService.buildWhere(user, filter === null || filter === void 0 ? void 0 : filter.where);
        }
        return this.loginActivityRepository.find(updatedFilter, options);
    }
    async findById(id, filter, options) {
        let updatedFilter;
        const user = await this.getCurrentUser();
        if (user.tenantId) {
            updatedFilter = {
                ...filter,
                where: this.tenantGuardService.buildWhere(user, undefined, id),
            };
            const record = await this.loginActivityRepository.findOne(updatedFilter, options);
            if (record) {
                return record;
            }
        }
        throw new rest_1.HttpErrors.NotFound();
    }
    async findOne(filter, options) {
        const updatedFilter = filter !== null && filter !== void 0 ? filter : new repository_1.FilterBuilder().build();
        const user = await this.getCurrentUser();
        if (user.tenantId) {
            updatedFilter.where = this.tenantGuardService.buildWhere(user, filter === null || filter === void 0 ? void 0 : filter.where);
        }
        return this.loginActivityRepository.findOne(updatedFilter, options);
    }
    async count(where, options) {
        let updatedWhere = where !== null && where !== void 0 ? where : new repository_1.WhereBuilder().build();
        const user = await this.getCurrentUser();
        if (user.tenantId) {
            updatedWhere = this.tenantGuardService.buildWhere(user, where);
        }
        return this.loginActivityRepository.count(updatedWhere, options);
    }
};
exports.LoginActivityHelperService = LoginActivityHelperService;
exports.LoginActivityHelperService = LoginActivityHelperService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, core_1.inject.getter(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(1, (0, core_1.inject)(core_2.TenantUtilitiesBindings.GuardService)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.LoginActivityRepository)),
    tslib_1.__metadata("design:paramtypes", [Function, core_2.TenantGuardService,
        repositories_1.LoginActivityRepository])
], LoginActivityHelperService);
//# sourceMappingURL=login-activity-helper.service.js.map